@@ -6,7 +6,7 @@ Mojolicious::Plugin::Riotjs - A Mojolicious  plugin for including riot.js .tag f
 
 =head1 VERSION
 
-0.01
+0.02
 
 =head1 DESCRIPTION
 
@@ -21,6 +21,14 @@ From the L<web page|https://muut.com/riotjs/>:
   A REACT-LIKE, 2.5KB USER INTERFACE LIBRARY
   Custom tags - Virtual DOM - Full stack - IE8
 
+=head2 Dependencies
+
+Riot is required for this module to work. You can install Riot with
+L<npm|https://www.npmjs.com/>:
+
+  $ sudo apt-get install npm
+  $ npm install riot
+
 =head1 SYNOPSIS
 
   use Mojolicious::Lite;
@@ -80,11 +88,35 @@ From the L<web page|https://muut.com/riotjs/>:
 =cut
 
 use Mojo::Base 'Mojolicious::Plugin';
+use Cwd ();
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
+
+$ENV{NODE_PATH} ||= '';
 
 =head1 METHODS
 
+=head2 node_paths
+
+  @paths = $self->node_paths($app);
+
+Returns the path to available "node_modules". This is used by L</register> to
+set the C<NODE_PATH> environment variable.
+
+The default is to look for "node_modules" in current directy and relative to
+L<project home|Mojolicious/home>. It will also use the current value of
+C<NODE_PATH> if already set.
+
+=cut
+
+sub node_paths {
+  my ($self, $app) = @_;
+  my %PATH;
+
+  return grep { -d and !$PATH{$_}++ } split(/:/, $ENV{NODE_PATH}), Cwd::abs_path('node_modules'),
+    $app->home->rel_dir('node_modules');
+}
+
 =head2 register
 
 Will register the L<Mojolicious::Plugin::Riotjs::Preprocessor> with the
@@ -95,6 +127,7 @@ Will register the L<Mojolicious::Plugin::Riotjs::Preprocessor> with the
 sub register {
   my ($self, $app, $config) = @_;
 
+  $ENV{NODE_PATH} = join ':', $self->node_paths($app);
   $app->plugin('AssetPack') unless eval { $app->asset };
   $app->asset->preprocessor('Mojolicious::Plugin::Riotjs::Preprocessor', {extensions => ['tag']});
 }
