@@ -1,4 +1,4 @@
-var riotCompiler = require('riot/compiler');
+var riot = require('riot');
 var stdin = process.stdin;
 var stdout = process.stdout;
 var content = '';
@@ -9,5 +9,5 @@ stdin.on('data', function (chunk) {
   content += chunk;
 });
 stdin.on('end', function () {
-  stdout.write(riotCompiler(content, {compact: process.env.RIOT_COMPACT ? true : false}));
+  stdout.write(riot.compile(content, {compact: process.env.RIOT_COMPACT ? true : false}));
 });
